function ctf_write_sam_targets(vertices,file)

% ctf_write_sam_targets - write a CTF SAM target file
%
% ctf_write_sam_targets(vertices,file)
%
% vertices - is Nx3 list of coordinates in CTF head coordinates (in cm).
% file - an output path/file
%
% The output file is an ascii text file in the following format:
%
% Number of Points
% x1 y1 z1
% x2 y2 z2
% .
% .
% .
% xn yn zn
%
% These vertex coordinates are contained in the input vertices
% matrix (Nx3).  The coordinate values must be in centimeters in
% the MEG Head Coordinate system (see ctf_read_mri for more about 
% the coordinate system).
%

% $Revision: 1.1 $ $Date: 2004/04/02 01:15:33 $

% Licence:  GNU GPL, no implied or express warranties
% History:  02/2004, Darren.Weber_at_radiology.ucsf.edu
%                    - adapted from an appendex to CTF document
%                    MRIViewer.pdf
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


ver = '[$Revision: 1.1 $]';
fprintf('\nCTF_WRITE_SAM_TARGETS [v%s]\n',ver(12:16));



%--------------------------------------------------
% output an ascii file

fid = fopen(file,'w');

if isequal(fid,-1),
    S=sprintf('Could not open file: "%s"',file);
    error(S);
else
    
    fprintf('...writing to file:\n   %s\n',file);
    fprintf('...writing CTF SAM target file, assuming head coordinates\n');
    tic;
    
    % Write vertices
    Nvertices = size(vertices,1);
    fprintf(fid,'%d\n',Nvertices);
    
    for v = 1:Nvertices,
      fprintf(fid,'%6.3f %6.3f %6.3f\n',vertices(v,1),vertices(v,2),vertices(v,3));
    end
    
    fclose(fid);
    
    t = toc;
    fprintf('...done (%6.2f sec).\n',t);
    
end

return
